====================
 ``zope.container``
====================


.. image:: https://img.shields.io/pypi/v/zope.container.svg
        :target: https://pypi.python.org/pypi/zope.container/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.container.svg
        :target: https://pypi.org/project/zope.container/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/zope.container.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.container

.. image:: https://readthedocs.org/projects/zopecontainer/badge/?version=latest
        :target: http://zopecontainer.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.container/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.container?branch=master


This package define interfaces of container components, and provides
container implementations such as a BTreeContainer and
OrderedContainer, as well as the base class used by ``zope.site.folder``
for the Folder implementation.

Documentation is hosted at https://zopecontainer.readthedocs.io
